
#!/bin/bash

# Stelle sicher, dass ROOT_DIR gesetzt ist
if [ -z "$ROOT_DIR" ]; then
    echo "❌ WARN: ROOT_DIR ist nicht gesetzt! Setze ROOT_DIR..."
    # Bestimme das Root-Verzeichnis des Git-Repos
    ROOT_DIR=$(git rev-parse --show-toplevel 2>/dev/null)

    # Falls das Repository nicht gefunden wurde, abbrechen
    if [ -z "$ROOT_DIR" ]; then
        echo "❌ Fehler: Kein Git-Repository gefunden!"
        exit 1
    fi

    # Setze die Variable für die aktuelle Shell-Sitzung
    export ROOT_DIR
    echo "✅ ROOT_DIR gesetzt auf: $ROOT_DIR"
fi

# Setze den Pfad zur .env.all Datei relativ zum Projekt-Root
ENV_FILE="$ROOT_DIR/env/.env.all"

# Prüfen, ob die Datei existiert
if [ ! -f "$ENV_FILE" ]; then
    echo "❌ Fehler: Die Datei $ENV_FILE existiert nicht!"
    exit 1
fi

echo "✅ ENV-Datei vorhanden: $ENV_FILE"

# Funktion: Alle Variablen exportieren
export_env_vars() {
    while IFS='=' read -r key value; do
        # Entferne führende und nachfolgende Leerzeichen
        key=$(echo "$key" | xargs)
        value=$(echo "$value" | xargs)

        # Falls die Zeile ein Kommentar oder leer ist, überspringen
        if [[ -z "$key" || "$key" =~ ^# || -z "$value" ]]; then
            continue
        fi

        # Entferne umschließende Anführungszeichen, falls vorhanden
        value=$(echo "$value" | sed -E 's/^"(.*)"$/\1/')

        # Exportiere die Variable
        export "$key=$value"
    done < "$ENV_FILE"
}

# Alle Variablen exportieren
export_env_vars

export SERVER_IP=$(curl -s https://api.ipify.org)

echo "🔹 Geladene Variablen:"
grep -o '^[^#]*' "$ENV_FILE" | cut -d '=' -f1 | while read -r var; do
    echo "$var=${!var}"  # Gibt die gesetzten Variablen mit ihrem Wert aus
done





